jabbatron
=========

Interactive installer script for Ubuntu.

* Author:  Laszlo Szathmary, 2012 (<jabba.laci@gmail.com>)
* Website: <http://ubuntuincident.wordpress.com/2012/02/29/jabbatron/>
* GitHub:  <https://github.com/jabbalaci/jabbatron>

If you have a newly installed (virgin) system,
you can easily update it with this script.

I've tested it with Python 2.7 under Ubuntu Linux.

Installation
------------

jabbatron is now available via pypi:

    sudo pip install jabbatron

Or, simply download `jabbatron.py` and launch it.

Screenshot
----------

    ###### Jabbatron 0.2.1 ########
    #  Jabbatron is good for you  #
    ###############################
    # main                        #
    ###############################
    (00)  The Ubuntu Incident (open blog)
    (00b) Python Adventures (open blog)
    (100) prepare HOME directory + install essential softwares...
    (110) development (C/C++/D compilers, oXygen XML Editor, etc.)...
    (09)  latex
    (120) github...
    (11)  tools (xsel, kdiff3, etc.)
    (130) Python for World Domination...
    (13)  multimedia (mplayer2, vlc, clementine, etc.)
    (14)  LAMP (set up a LAMP environment)
    (15)  gimp (2.8.x)
    (140) Ubuntu (tweaks, extra softwares)...
    (150) databases (sqlite3, mongodb, mysql)...
    (160) browser(s)...
    (170) install from source (mc, tesseract3)...
    (180) games...
    (190) Java...
    (q)   quit
    >>>
